Index: pacman-optimize
===================================================================
RCS file: /home/cvs-pacman/pacman-lib/scripts/pacman-optimize,v
retrieving revision 1.4
diff -u -r1.4 pacman-optimize
--- pacman-optimize	28 Dec 2006 18:19:25 -0000	1.4
+++ pacman-optimize	31 Dec 2006 15:00:28 -0000
@@ -76,31 +76,79 @@
 # don't let pacman run while we do this
 touch /tmp/pacman.lck
 
+# check if $dbroot is a mounted partition
+mounted=`cat /etc/mtab | grep $dbroot`
+if [ -n $mounted ]; then
+    dev=`echo $mounted | awk {'print $1'}`
+    fs=`echo $mounted | awk {'print $3'}`
+    opts=`echo $mounted | awk {'print $4'}`
+    
+    # step 1: sum the old db
+    echo "==> md5sum'ing the old database..."
+    find $dbroot -type f | sort | xargs md5sum >/tmp/pacsums.old
+    
+    # step 2: backup the old db and copy the entire db directory to a new one
+    echo "==> tar'ing the old database..."
+    tar -czpsf /tmp/pacmanDB.bak.tgz $dbroot/
+    echo "==> copying $dbroot..."
+    cp -a $dbroot $dbroot.new
+    rm -rf $dbroot/*
+    mv $dbroot.new/* $dbroot/
+    
+    # step 3: sum the new one
+    echo "==> md5sum'ing the new database..."
+    find $dbroot -type f | sort | xargs md5sum >/tmp/pacsums.new
+    
+    # step 4: compare the sums
+    echo "==> checking integrity..."
+    diff /tmp/pacsums.old /tmp/pacsums.new >/dev/null 2>&1
+    if [ $? -ne 0 ]; then
+        # failed, restore everything
+        rm -rf $dbroot/*
+        tar -zxvpf /tmp/pacmanDB.bak.tgz -C $dbroot/
+        rm -f /tmp/pacsums.old /tmp/pacsums.new /tmp/pacmanDB.bak.tgz
+        die_r "integrity check FAILED, reverting to old database"
+    fi
+    
+    # step 5: remove the backup
+    echo "==> removing old database..."
+    rm -rf /tmp/pacmanDB.bak.tgz || die_r "error removing backup pacmanDB.bak.tgz"
+    
+    # remove the lock and sum files
+    rm -f /tmp/pacman.lck /tmp/pacsums.old /tmp/pacsums.new
+    
+    echo
+    echo "Finished.  Your pacman database has been optimized."
+    echo
+    
+    exit 0
+fi
+
 # step 1: sum the old db
 echo "==> md5sum'ing the old database..."
 find $dbroot -type f | sort | xargs md5sum >/tmp/pacsums.old 
 
-# step 1: copy the entire db directory to a new one
+# step 2: copy the entire db directory to a new one
 echo "==> copying $dbroot..."
 cp -a $dbroot $dbroot.new || die_r "error copying $dbroot"
 
-# step 2: switch the directory names and sum the new one
+# step 3: switch the directory names and sum the new one
 echo "==> md5sum'ing the new database..."
 mv $dbroot $dbroot.bak || die_r "error renaming $dbroot"
 mv $dbroot.new $dbroot || die_r "error renaming $dbroot.new"
 find $dbroot -type f | sort | xargs md5sum >/tmp/pacsums.new
 
-# step 3: compare sums
+# step 4: compare sums
 echo "==> checking integrity..."
 diff /tmp/pacsums.old /tmp/pacsums.new >/dev/null 2>&1
 if [ $? -ne 0 ]; then
 	# failed, move the old one back into place
 	rm -rf $dbroot
	mv $dbroot.bak $dbroot
 	die_r "integrity check FAILED, reverting to old database"
 fi
 
-# step 4: remove the backup
+# step 5: remove the backup
 echo "==> removing old database..."
 rm -rf $dbroot.bak || die_r "error removing backup $dbroot.bak"
 
